==> zio-aws-ec2_2.12-7.21.15.12-sources.jar: zio/aws/ec2/model/RegisterTransitGatewayMulticastGroupSourcesRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{
  NetworkInterfaceId,
  TransitGatewayMulticastDomainId
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class RegisterTransitGatewayMulticastGroupSourcesRequest(
    transitGatewayMulticastDomainId: TransitGatewayMulticastDomainId,
    groupIpAddress: Optional[String] = Optional.Absent,
    networkInterfaceIds: Iterable[NetworkInterfaceId],
    dryRun: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.RegisterTransitGatewayMulticastGroupSourcesRequest = {
    import RegisterTransitGatewayMulticastGroupSourcesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.RegisterTransitGatewayMulticastGroupSourcesRequest
      .builder()
      .transitGatewayMulticastDomainId(
        TransitGatewayMulticastDomainId.unwrap(
          transitGatewayMulticastDomainId
        ): java.lang.String
      )
      .optionallyWith(groupIpAddress.map(value => value: java.lang.String))(
        _.groupIpAddress
      )
      .networkInterfaceIds(networkInterfaceIds.map { item =>
        NetworkInterfaceId.unwrap(item): java.lang.String
      }.asJavaCollection)
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.RegisterTransitGatewayMulticastGroupSourcesRequest.ReadOnly =
    zio.aws.ec2.model.RegisterTransitGatewayMulticastGroupSourcesRequest
      .wrap(buildAwsValue())
}
object RegisterTransitGatewayMulticastGroupSourcesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.RegisterTransitGatewayMulticastGroupSourcesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.RegisterTransitGatewayMulticastGroupSourcesRequest =
      zio.aws.ec2.model.RegisterTransitGatewayMulticastGroupSourcesRequest(
        transitGatewayMulticastDomainId,
        groupIpAddress.map(value => value),
        networkInterfaceIds,
        dryRun.map(value => value)
      )
    def transitGatewayMulticastDomainId: TransitGatewayMulticastDomainId
    def groupIpAddress: Optional[String]
    def networkInterfaceIds: List[NetworkInterfaceId]
    def dryRun: Optional[Boolean]
    def getTransitGatewayMulticastDomainId
        : ZIO[Any, Nothing, TransitGatewayMulticastDomainId] =
      ZIO.succeed(transitGatewayMulticastDomainId)
    def getGroupIpAddress: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("groupIpAddress", groupIpAddress)
    def getNetworkInterfaceIds: ZIO[Any, Nothing, List[NetworkInterfaceId]] =
      ZIO.succeed(networkInterfaceIds)
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.RegisterTransitGatewayMulticastGroupSourcesRequest
  ) extends zio.aws.ec2.model.RegisterTransitGatewayMulticastGroupSourcesRequest.ReadOnly {
    override val transitGatewayMulticastDomainId
        : TransitGatewayMulticastDomainId = zio.aws.ec2.model.primitives
      .TransitGatewayMulticastDomainId(impl.transitGatewayMulticastDomainId())
    override val groupIpAddress: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.groupIpAddress())
      .map(value => value: String)
    override val networkInterfaceIds: List[NetworkInterfaceId] = impl
      .networkInterfaceIds()
      .asScala
      .map { item =>
        zio.aws.ec2.model.primitives.NetworkInterfaceId(item)
      }
      .toList
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.RegisterTransitGatewayMulticastGroupSourcesRequest
  ): zio.aws.ec2.model.RegisterTransitGatewayMulticastGroupSourcesRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-6.20.115.1-sources.jar: zio/aws/ec2/model/RegisterTransitGatewayMulticastGroupSourcesRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{
  NetworkInterfaceId,
  TransitGatewayMulticastDomainId
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class RegisterTransitGatewayMulticastGroupSourcesRequest(
    transitGatewayMulticastDomainId: TransitGatewayMulticastDomainId,
    groupIpAddress: Optional[String] = Optional.Absent,
    networkInterfaceIds: Iterable[NetworkInterfaceId]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.RegisterTransitGatewayMulticastGroupSourcesRequest = {
    import RegisterTransitGatewayMulticastGroupSourcesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.RegisterTransitGatewayMulticastGroupSourcesRequest
      .builder()
      .transitGatewayMulticastDomainId(
        TransitGatewayMulticastDomainId.unwrap(
          transitGatewayMulticastDomainId
        ): java.lang.String
      )
      .optionallyWith(groupIpAddress.map(value => value: java.lang.String))(
        _.groupIpAddress
      )
      .networkInterfaceIds(networkInterfaceIds.map { item =>
        NetworkInterfaceId.unwrap(item): java.lang.String
      }.asJavaCollection)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.RegisterTransitGatewayMulticastGroupSourcesRequest.ReadOnly =
    zio.aws.ec2.model.RegisterTransitGatewayMulticastGroupSourcesRequest
      .wrap(buildAwsValue())
}
object RegisterTransitGatewayMulticastGroupSourcesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.RegisterTransitGatewayMulticastGroupSourcesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.RegisterTransitGatewayMulticastGroupSourcesRequest =
      zio.aws.ec2.model.RegisterTransitGatewayMulticastGroupSourcesRequest(
        transitGatewayMulticastDomainId,
        groupIpAddress.map(value => value),
        networkInterfaceIds
      )
    def transitGatewayMulticastDomainId: TransitGatewayMulticastDomainId
    def groupIpAddress: Optional[String]
    def networkInterfaceIds: List[NetworkInterfaceId]
    def getTransitGatewayMulticastDomainId
        : ZIO[Any, Nothing, TransitGatewayMulticastDomainId] =
      ZIO.succeed(transitGatewayMulticastDomainId)
    def getGroupIpAddress: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("groupIpAddress", groupIpAddress)
    def getNetworkInterfaceIds: ZIO[Any, Nothing, List[NetworkInterfaceId]] =
      ZIO.succeed(networkInterfaceIds)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.RegisterTransitGatewayMulticastGroupSourcesRequest
  ) extends zio.aws.ec2.model.RegisterTransitGatewayMulticastGroupSourcesRequest.ReadOnly {
    override val transitGatewayMulticastDomainId
        : TransitGatewayMulticastDomainId = zio.aws.ec2.model.primitives
      .TransitGatewayMulticastDomainId(impl.transitGatewayMulticastDomainId())
    override val groupIpAddress: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.groupIpAddress())
      .map(value => value: String)
    override val networkInterfaceIds: List[NetworkInterfaceId] = impl
      .networkInterfaceIds()
      .asScala
      .map { item =>
        zio.aws.ec2.model.primitives.NetworkInterfaceId(item)
      }
      .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.RegisterTransitGatewayMulticastGroupSourcesRequest
  ): zio.aws.ec2.model.RegisterTransitGatewayMulticastGroupSourcesRequest.ReadOnly =
    new Wrapper(impl)
}
